# Open LISA SDK

This SDK provides an interface to interact with the [Open LISA Server](https://github.com/aalvarezwindey/Open-LISA-Server). The server must be integrated with the instruments of interest and running in a known IP and port (TCP connections) or you must known the serial port (SERIAL connections) for the client side in order to be able to connect via this SDK.

## Installation

```
pip install open-lisa-sdk
```
